package Bencher::ScenarioR::DateModules::Overhead;

our $VERSION = 0.004; # VERSION

our $results = [
  [
    200,
    "OK",
    [
      {
        errors => 0.00053,
        mod_overhead_time => 60.7,
        participant => "DateTime::Duration",
        proc_private_dirty_size => 1,
        proc_rss_size => 4.5,
        proc_size => 16,
        samples => 20,
        time => 65,
        vs_slowest => 1,
      },
      {
        errors => 0.00016,
        mod_overhead_time => 55.7,
        participant => "DateTime",
        proc_private_dirty_size => 11,
        proc_rss_size => 15,
        proc_size => 44,
        samples => 20,
        time => 60,
        vs_slowest => 1.1,
      },
      {
        errors => 2.1e-05,
        mod_overhead_time => 12.7,
        participant => "Time::Piece",
        proc_private_dirty_size => 0.82,
        proc_rss_size => 4.1,
        proc_size => 16,
        samples => 21,
        time => 17,
        vs_slowest => 3.8,
      },
      {
        errors => 0.00016,
        mod_overhead_time => 5.7,
        participant => "Time::Moment",
        proc_private_dirty_size => 2,
        proc_rss_size => 5,
        proc_size => 20,
        samples => 20,
        time => 10,
        vs_slowest => 5,
      },
      {
        errors => 2.7e-05,
        mod_overhead_time => 7.7,
        participant => "Time::Local",
        proc_private_dirty_size => 2.3,
        proc_rss_size => 5.9,
        proc_size => 19,
        samples => 20,
        time => 12,
        vs_slowest => 5.3,
      },
      {
        errors => 2.5e-05,
        mod_overhead_time => 3.9,
        participant => "DateTime::Tiny",
        proc_private_dirty_size => 1.4,
        proc_rss_size => 4.8,
        proc_size => 19,
        samples => 20,
        time => 8.2,
        vs_slowest => 7.9,
      },
      {
        errors => 6.2e-06,
        mod_overhead_time => 0,
        participant => "perl -e1 (baseline)",
        proc_private_dirty_size => 11,
        proc_rss_size => 15,
        proc_size => 44,
        samples => 20,
        time => 4.3,
        vs_slowest => 15,
      },
    ],
    {
      "func.bencher_args"              => {
                                            action => "bench",
                                            note => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
                                            scenario_module => "DateModules::Overhead",
                                          },
      "func.bencher_version"           => undef,
      "func.code_startup"              => undef,
      "func.cpu_info"                  => [
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 0,
                                              speed                        => 2600.007,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 1,
                                              speed                        => 2865.734,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 2,
                                              speed                        => 2600.007,
                                              stepping                     => 4,
                                            },
                                            {
                                              address_width                => 64,
                                              architecture                 => "AMD-64",
                                              bus_speed                    => undef,
                                              data_width                   => 64,
                                              family                       => 6,
                                              flags                        => [
                                                                                "fpu",
                                                                                "vme",
                                                                                "de",
                                                                                "pse",
                                                                                "tsc",
                                                                                "msr",
                                                                                "pae",
                                                                                "mce",
                                                                                "cx8",
                                                                                "apic",
                                                                                "sep",
                                                                                "mtrr",
                                                                                "pge",
                                                                                "mca",
                                                                                "cmov",
                                                                                "pat",
                                                                                "pse36",
                                                                                "clflush",
                                                                                "dts",
                                                                                "acpi",
                                                                                "mmx",
                                                                                "fxsr",
                                                                                "sse",
                                                                                "sse2",
                                                                                "ss",
                                                                                "ht",
                                                                                "tm",
                                                                                "pbe",
                                                                                "syscall",
                                                                                "nx",
                                                                                "pdpe1gb",
                                                                                "rdtscp",
                                                                                "lm",
                                                                                "constant_tsc",
                                                                                "arch_perfmon",
                                                                                "pebs",
                                                                                "bts",
                                                                                "rep_good",
                                                                                "nopl",
                                                                                "xtopology",
                                                                                "nonstop_tsc",
                                                                                "aperfmperf",
                                                                                "eagerfpu",
                                                                                "pni",
                                                                                "pclmulqdq",
                                                                                "dtes64",
                                                                                "monitor",
                                                                                "ds_cpl",
                                                                                "vmx",
                                                                                "smx",
                                                                                "est",
                                                                                "tm2",
                                                                                "ssse3",
                                                                                "fma",
                                                                                "cx16",
                                                                                "xtpr",
                                                                                "pdcm",
                                                                                "pcid",
                                                                                "sse4_1",
                                                                                "sse4_2",
                                                                                "x2apic",
                                                                                "movbe",
                                                                                "popcnt",
                                                                                "tsc_deadline_timer",
                                                                                "aes",
                                                                                "xsave",
                                                                                "avx",
                                                                                "f16c",
                                                                                "rdrand",
                                                                                "lahf_lm",
                                                                                "abm",
                                                                                "3dnowprefetch",
                                                                                "ida",
                                                                                "arat",
                                                                                "epb",
                                                                                "pln",
                                                                                "pts",
                                                                                "dtherm",
                                                                                "tpr_shadow",
                                                                                "vnmi",
                                                                                "flexpriority",
                                                                                "ept",
                                                                                "vpid",
                                                                                "fsgsbase",
                                                                                "tsc_adjust",
                                                                                "bmi1",
                                                                                "hle",
                                                                                "avx2",
                                                                                "smep",
                                                                                "bmi2",
                                                                                "erms",
                                                                                "invpcid",
                                                                                "rtm",
                                                                                "rdseed",
                                                                                "adx",
                                                                                "smap",
                                                                                "xsaveopt",
                                                                              ],
                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                              manufacturer                 => "GenuineIntel",
                                              model                        => 61,
                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
                                              number_of_cores              => 2,
                                              number_of_logical_processors => 4,
                                              processor_id                 => 3,
                                              speed                        => 2754.281,
                                              stepping                     => 4,
                                            },
                                          ],
      "func.elapsed_time"              => 4.74987506866455,
      "func.module_startup"            => 1,
      "func.module_versions"           => {
                                            "__PACKAGE__"                              => "1.040",
                                            "Bencher::Scenario::DateModules::Overhead" => undef,
                                            "Benchmark::Dumb"                          => "0.10",
                                            "DateTime"                                 => 1.36,
                                            "DateTime::Duration"                       => 1.36,
                                            "DateTime::Tiny"                           => 1.06,
                                            "Devel::Platform::Info"                    => 0.16,
                                            "perl"                                     => "v5.24.0",
                                            "Sys::Info"                                => 0.78,
                                            "Time::Local"                              => "1.2300",
                                            "Time::Moment"                             => 0.38,
                                            "Time::Piece"                              => 1.31,
                                          },
      "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 6]],
      "func.platform_info"             => {
                                            archname => "x86_64",
                                            codename => "rosa",
                                            is32bit  => 0,
                                            is64bit  => 1,
                                            kernel   => "linux-3.19.0-32-generic",
                                            kname    => "Linux",
                                            kvers    => "3.19.0-32-generic",
                                            osflag   => "linux",
                                            oslabel  => "LinuxMint",
                                            osname   => "GNU/Linux",
                                            osvers   => 17.3,
                                            source   => {
                                                          "cat /etc/.issue" => "",
                                                          "cat /etc/issue"  => "Linux Mint 17.3 Rosa \\n \\l",
                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 17.3 Rosa\nRelease:\t17.3\nCodename:\trosa",
                                                          "uname -a"        => "Linux backpacker 3.19.0-32-generic #37~14.04.1-Ubuntu SMP Thu Oct 22 09:41:40 UTC 2015 x86_64 x86_64 x86_64 GNU/Linux",
                                                          "uname -m"        => "x86_64",
                                                          "uname -o"        => "GNU/Linux",
                                                          "uname -r"        => "3.19.0-32-generic",
                                                          "uname -s"        => "Linux",
                                                        },
                                          },
      "func.precision"                 => 0,
      "func.scenario_module"           => "Bencher::Scenario::DateModules::Overhead",
      "func.scenario_module_md5sum"    => "b92b6e39c4b5d854a5fa9851b88e9758",
      "func.scenario_module_mtime"     => 1503796297,
      "func.scenario_module_sha1sum"   => "5ebfd278d72fa0753b8f1f5cf1309d768ec11d6e",
      "func.scenario_module_sha256sum" => "f8df64a57fc589ecb08bf12173acec12e29ff2ff1768b099eba1a06cf7f6809e",
      "func.time_end"                  => 1503798512.62551,
      "func.time_factor"               => 1000,
      "func.time_start"                => 1503798507.87563,
      "table.field_aligns"             => [
                                            "left",
                                            "left",
                                            "left",
                                            "left",
                                            "number",
                                            "number",
                                            "number",
                                            "number",
                                            "number",
                                          ],
      "table.field_units"              => [undef, "MB", "MB", "MB", "ms", "ms"],
      "table.fields"                   => [
                                            "participant",
                                            "proc_private_dirty_size",
                                            "proc_rss_size",
                                            "proc_size",
                                            "time",
                                            "mod_overhead_time",
                                            "vs_slowest",
                                            "errors",
                                            "samples",
                                          ],
    },
  ],
];

1;
# ABSTRACT: Overhead of date/duration modules

=head1 DESCRIPTION

This module is automatically generated by Pod::Weaver::Plugin::Bencher::Scenario during distribution build.

A Bencher::ScenarioR::* module contains the raw result of sample benchmark and might be useful for some stuffs later.

